@@ -20,14 +20,16 @@
 SystrayIcon::SystrayIcon()
     : QObject()
 {
+    m_trayIcon = new QSystemTrayIcon();
+
     setIconColor(intToIconColorEnum(SettingsManager::self()->trayIconType()));
-    m_trayIcon.setToolTip(i18nc("@info:tooltip",
-                                "Kasts\n"
-                                "Middle-click to play/pause"));
+    m_trayIcon->setToolTip(i18nc("@info:tooltip",
+                                 "Kasts\n"
+                                 "Middle-click to play/pause"));
 
     QMenu *menu = new QMenu();
 
-    connect(&m_trayIcon, &QSystemTrayIcon::activated, this, [this](QSystemTrayIcon::ActivationReason reason) {
+    connect(m_trayIcon, &QSystemTrayIcon::activated, this, [this](QSystemTrayIcon::ActivationReason reason) {
         if (reason == QSystemTrayIcon::Trigger) {
             Q_EMIT raiseWindow();
         } else if (reason == QSystemTrayIcon::MiddleClick) {
@@ -37,9 +39,9 @@ SystrayIcon::SystrayIcon()
 
     connect(SettingsManager::self(), &SettingsManager::showTrayIconChanged, this, [this]() {
         if (SettingsManager::self()->showTrayIcon()) {
-            m_trayIcon.show();
+            m_trayIcon->show();
         } else {
-            m_trayIcon.hide();
+            m_trayIcon->hide();
         }
     });
 
@@ -117,13 +119,13 @@ SystrayIcon::SystrayIcon()
     QAction *quitAction = new QAction(i18nc("@action:inmenu", "Quit"), this);
     quitAction->setIcon(QIcon::fromTheme(QStringLiteral("application-exit")));
 
-    connect(quitAction, &QAction::triggered, QCoreApplication::instance(), QCoreApplication::quit);
+    connect(quitAction, &QAction::triggered, QCoreApplication::instance(), QCoreApplication::quit, Qt::QueuedConnection);
     menu->addAction(quitAction);
 
-    m_trayIcon.setContextMenu(menu);
+    m_trayIcon->setContextMenu(menu);
 
     if (SettingsManager::self()->showTrayIcon()) {
-        m_trayIcon.show();
+        m_trayIcon->show();
     }
 }
 #else
@@ -148,13 +150,13 @@ void SystrayIcon::setIconColor(SystrayIcon::IconColor iconColor)
     // do not specify svg-extension; icon will not be visible due to [QTBUG-53550]
     switch (iconColor) {
     case SystrayIcon::IconColor::Colorful:
-        m_trayIcon.setIcon(QIcon(QStringLiteral(":/icons/kasts")));
+        m_trayIcon->setIcon(QIcon(QStringLiteral(":/icons/kasts")));
         break;
     case SystrayIcon::IconColor::Light:
-        m_trayIcon.setIcon(QIcon(QStringLiteral(":/icons/kasts-tray-light")));
+        m_trayIcon->setIcon(QIcon(QStringLiteral(":/icons/kasts-tray-light")));
         break;
     case SystrayIcon::IconColor::Dark:
-        m_trayIcon.setIcon(QIcon(QStringLiteral(":/icons/kasts-tray-dark")));
+        m_trayIcon->setIcon(QIcon(QStringLiteral(":/icons/kasts-tray-dark")));
         break;
     }
 #endif
